@@ -25,9 +25,7 @@ from wnm.utils import (
     update_counters,
 )
 
-logging.basicConfig(level=logging.INFO)
-# Info level logging for sqlalchemy is too verbose, only use when needed
-logging.getLogger("sqlalchemy.engine.Engine").disabled = True
+# Logging is configured in config.py based on --loglevel and --quiet flags
 
 
 # A storage place for ant node data
@@ -163,8 +161,15 @@ def main():
 
     # Do we already have nodes
     if metrics["total_nodes"] == 0:
-        # Are we migrating an anm server
-        if options.init and options.migrate_anm:
+        # Survey for existing nodes if:
+        # 1. Migrating from anm (--init --migrate_anm)
+        # 2. Initializing with antctl to import existing antctl nodes (--init with antctl+user/antctl+sudo)
+        should_survey = (
+            (options.init and options.migrate_anm) or
+            (options.init and machine_config.process_manager and machine_config.process_manager.startswith("antctl"))
+        )
+
+        if should_survey:
             Workers = survey_machine(machine_config) or []
             if Workers:
                 if options.dry_run:
@@ -196,7 +201,11 @@ def main():
 
     # Check for reports
     if options.report:
-        from wnm.reports import generate_node_status_report, generate_node_status_details_report
+        from wnm.reports import (
+            generate_node_status_report,
+            generate_node_status_details_report,
+            generate_influx_resources_report,
+        )
 
         # If survey action is specified, run it first
         if options.force_action == "survey":
@@ -220,6 +229,10 @@ def main():
             report_output = generate_node_status_details_report(
                 S, options.service_name, options.report_format
             )
+        elif options.report == "influx-resources":
+            report_output = generate_influx_resources_report(
+                S, options.service_name
+            )
         else:
             report_output = f"Unknown report type: {options.report}"
 
@@ -229,6 +242,13 @@ def main():
 
     # Check for forced actions
     if options.force_action:
+        # Teardown requires confirmation for safety
+        if options.force_action == "teardown" and not options.confirm:
+            logging.error("Teardown requires --confirm flag for safety")
+            print("Error: Teardown requires --confirm flag. This will remove all nodes.")
+            os.remove(LOCK_FILE)
+            sys.exit(1)
+
         logging.info(f"Executing forced action: {options.force_action}")
         executor = ActionExecutor(S)
         this_action = executor.execute_forced_action(
