@@ -95,6 +95,8 @@ def _detect_process_manager_mode():
             # Remove sqlite:/// prefix if present
             if dbpath_arg.startswith("sqlite:///"):
                 dbpath_arg = dbpath_arg[10:]
+            # Expand ~ to home directory
+            dbpath_arg = os.path.expanduser(dbpath_arg)
             db_locations.append(dbpath_arg)
             break
 
@@ -104,8 +106,9 @@ def _detect_process_manager_mode():
         # Remove sqlite:/// prefix if present
         if dbpath_env.startswith("sqlite:///"):
             dbpath_env = dbpath_env[10:]
-        # Expand variables like $HOME
+        # Expand variables like $HOME and ~ for home directory
         dbpath_env = os.path.expandvars(dbpath_env)
+        dbpath_env = os.path.expanduser(dbpath_env)
         db_locations.append(dbpath_env)
 
     # Add platform-specific default locations
@@ -227,6 +230,7 @@ def load_config():
 
     c.add("-c", "--config", is_config_file=True, help="config file path")
     c.add("-v", help="verbose", action="store_true")
+    c.add("-q", "--quiet", help="Quiet mode (suppress all output except errors)", action="store_true")
     c.add("--version", help="Show version and exit", action="store_true")
     c.add("--remove_lockfile", help="Remove the lock file and exit", action="store_true")
     c.add(
@@ -235,14 +239,13 @@ def load_config():
         help="Path to the database",
         default=DEFAULT_DB_PATH,
     )
-    c.add("--loglevel", env_var="LOGLEVEL", help="Log level")
+    c.add("--loglevel", env_var="LOGLEVEL", help="Log level (DEBUG, INFO, WARNING, ERROR, CRITICAL)", default="INFO")
     c.add(
         "--dry_run", env_var="DRY_RUN", help="Do not save changes", action="store_true"
     )
     c.add("--init", help="Initialize a cluster", action="store_true")
     c.add("--migrate_anm", help="Migrate a cluster from anm", action="store_true")
-    c.add("--teardown", help="Remove a cluster", action="store_true")
-    c.add("--confirm", help="Confirm teardown without ui", action="store_true")
+    c.add("--confirm", help="Confirm destructive operations (required for teardown)", action="store_true")
     c.add("--node_cap", env_var="NODE_CAP", help="Node Capacity")
     c.add("--cpu_less_than", env_var="CPU_LESS_THAN", help="CPU Add Threshold")
     c.add("--cpu_remove", env_var="CPU_REMOVE", help="CPU Remove Threshold")
@@ -340,8 +343,8 @@ def load_config():
     c.add(
         "--report",
         env_var="REPORT",
-        help="Generate a report: node-status, node-status-details",
-        choices=["node-status", "node-status-details"],
+        help="Generate a report: node-status, node-status-details, influx-resources",
+        choices=["node-status", "node-status-details", "influx-resources"],
     )
     c.add(
         "--report_format",
@@ -360,11 +363,32 @@ def load_config():
     c.add(
         "--process_manager",
         env_var="PROCESS_MANAGER",
-        help="Process manager to use: systemd+sudo, systemd+user, setsid+sudo, setsid+user, launchd+sudo, launchd+user",
-        choices=["systemd+sudo", "systemd+user", "setsid+sudo", "setsid+user", "launchd+sudo", "launchd+user"],
+        help="Process manager to use: systemd+sudo, systemd+user, setsid+sudo, setsid+user, launchd+sudo, launchd+user, antctl+sudo, antctl+user",
+        choices=["systemd+sudo", "systemd+user", "setsid+sudo", "setsid+user", "launchd+sudo", "launchd+user", "antctl+sudo", "antctl+user"],
+    )
+    c.add(
+        "--no_upnp",
+        env_var="NO_UPNP",
+        help="Disable UPnP port forwarding on nodes (default: enabled)",
+        action="store_true",
     )
 
     options = c.parse_known_args()[0] or []
+
+    # Configure logging level based on options
+    if options.quiet:
+        log_level = logging.ERROR
+    elif options.loglevel:
+        # Convert string to logging level
+        log_level = getattr(logging, options.loglevel.upper(), logging.INFO)
+    else:
+        log_level = logging.INFO
+
+    # Set the logging level
+    logging.basicConfig(level=log_level, force=True)
+    # Info level logging for sqlalchemy is too verbose, only use when needed
+    logging.getLogger("sqlalchemy.engine.Engine").disabled = True
+
     # Return the first result from parse_known_args, ignore unknown options
     return options
 
@@ -482,6 +506,8 @@ def merge_config_changes(options, machine_config):
         cfg["start_args"] = options.start_args
     if options.process_manager and options.process_manager != machine_config.process_manager:
         cfg["process_manager"] = options.process_manager
+    if hasattr(options, 'no_upnp') and bool(options.no_upnp) != bool(machine_config.no_upnp):
+        cfg["no_upnp"] = bool(options.no_upnp)
 
     return cfg
 
@@ -517,10 +543,10 @@ def load_anm_config(options):
     )
     anm_config["cpu_remove"] = int(os.getenv("CpuRemove") or _get_option(options, "cpu_remove") or 70)
     anm_config["mem_less_than"] = int(
-        os.getenv("MemLessThan") or _get_option(options, "mem_less_than") or 70
+        os.getenv("MemLessThan") or _get_option(options, "mem_less_than") or 60
     )
-    anm_config["mem_remove"] = int(os.getenv("MemRemove") or _get_option(options, "mem_remove") or 90)
-    anm_config["hd_less_than"] = int(os.getenv("HDLessThan") or _get_option(options, "hd_less_than") or 70)
+    anm_config["mem_remove"] = int(os.getenv("MemRemove") or _get_option(options, "mem_remove") or 75)
+    anm_config["hd_less_than"] = int(os.getenv("HDLessThan") or _get_option(options, "hd_less_than") or 75)
     anm_config["hd_remove"] = int(os.getenv("HDRemove") or _get_option(options, "hd_remove") or 90)
     anm_config["delay_start"] = int(os.getenv("DelayStart") or _get_option(options, "delay_start") or 300)
     anm_config["delay_upgrade"] = int(
@@ -598,6 +624,9 @@ def load_anm_config(options):
     else:
         anm_config["process_manager"] = "systemd+user"
 
+    # UPnP setting (defaults to True/enabled)
+    anm_config["no_upnp"] = bool(_get_option(options, "no_upnp", False))
+
     return anm_config
 
 
@@ -626,17 +655,6 @@ def migrate_anm(options):
         return False
 
 
-# Teardown the machine
-def teardown_machine(machine_config):
-    logging.info("Teardown machine")
-    pass
-    # disable cron
-    # with S() as session:
-    #     select Nodes
-    #     for node in nodes:
-    #         delete node
-
-
 def define_machine(options):
     if not options.rewards_address:
         logging.warning("Rewards Address is required")
@@ -663,9 +681,9 @@ def define_machine(options):
         "node_cap": int(_get_option(options, "node_cap") or 20),
         "cpu_less_than": int(_get_option(options, "cpu_less_than") or 50),
         "cpu_remove": int(_get_option(options, "cpu_remove") or 70),
-        "mem_less_than": int(_get_option(options, "mem_less_than") or 70),
-        "mem_remove": int(_get_option(options, "mem_remove") or 90),
-        "hd_less_than": int(_get_option(options, "hd_less_than") or 70),
+        "mem_less_than": int(_get_option(options, "mem_less_than") or 60),
+        "mem_remove": int(_get_option(options, "mem_remove") or 75),
+        "hd_less_than": int(_get_option(options, "hd_less_than") or 75),
         "hd_remove": int(_get_option(options, "hd_remove") or 90),
         "delay_start": int(_get_option(options, "delay_start") or 300),
         "delay_upgrade": int(_get_option(options, "delay_upgrade") or 300),
@@ -690,6 +708,14 @@ def define_machine(options):
         "metrics_port_start": int(_get_option(options, "metrics_port_start") or 13),
         "environment": _get_option(options, "environment") or "",
         "start_args": _get_option(options, "start_args") or "",
+        "max_concurrent_upgrades": 1,
+        "max_concurrent_starts": 2,
+        "max_concurrent_removals": 1,
+        "node_removal_strategy": "youngest",
+        "max_node_per_container": 200,
+        "min_container_count": 1,
+        "docker_image": "iweave/antnode:latest",
+        "no_upnp": bool(_get_option(options, "no_upnp", False)),
     }
 
     # Set default process manager based on platform if not specified
@@ -724,11 +750,32 @@ def apply_config_updates(config_updates):
 # Load options now so we know what database to load
 options = load_config()
 
-# Skip database initialization for --version and --remove_lockfile
-# These flags should work without any database or lock file checks
-_SKIP_DB_INIT = getattr(options, 'version', False) or getattr(options, 'remove_lockfile', False)
+# Expand ~ and environment variables in dbpath if needed
+if hasattr(options, 'dbpath') and options.dbpath:
+    # Handle both bare paths and sqlite:/// URLs
+    if options.dbpath.startswith("sqlite:///"):
+        path_part = options.dbpath[10:]
+        path_part = os.path.expandvars(path_part)
+        path_part = os.path.expanduser(path_part)
+        options.dbpath = f"sqlite:///{path_part}"
+    else:
+        # If it's a bare path without sqlite:///, expand and re-add prefix
+        path_part = os.path.expandvars(options.dbpath)
+        path_part = os.path.expanduser(path_part)
+        if not path_part.startswith("sqlite:///"):
+            options.dbpath = f"sqlite:///{path_part}"
+        else:
+            options.dbpath = path_part
 
-# Setup Database engine (skip if --version or --remove_lockfile)
+# Skip database initialization for --version, --remove_lockfile, and test mode
+# These cases should work without any database or lock file checks
+_SKIP_DB_INIT = (
+    getattr(options, 'version', False)
+    or getattr(options, 'remove_lockfile', False)
+    or os.getenv("WNM_TEST_MODE")
+)
+
+# Setup Database engine (skip if --version, --remove_lockfile, or test mode)
 if not _SKIP_DB_INIT:
     engine = create_engine(options.dbpath, echo=True)
     # Generate ORM
@@ -737,7 +784,7 @@ if not _SKIP_DB_INIT:
     session_factory = sessionmaker(bind=engine)
     S = scoped_session(session_factory)
 else:
-    # Create dummy objects for --version and --remove_lockfile
+    # Create dummy objects for --version, --remove_lockfile, or test mode
     engine = None
     S = None
 
@@ -808,17 +855,6 @@ else:
     if options.init:
         logging.warning("Machine already initialized")
         sys.exit(1)
-    # Initate a teardown of the machine
-    if options.teardown:
-        if options.confirm:
-            if options.dry_run:
-                logging.info("DRY_RUN: Initiate Teardown")
-            else:
-                teardown_machine(machine_config)
-            sys.exit(0)
-        else:
-            logging.warning("Please confirm the teardown with --confirm")
-            sys.exit(1)
     # Get Machine from Row (skip in test mode or when using --version/--remove_lockfile)
     if not os.getenv("WNM_TEST_MODE") and not _SKIP_DB_INIT:
         machine_config = machine_config[0]
