@@ -99,6 +99,16 @@ class Machine(Base):
     # Process manager type
     process_manager: Mapped[Optional[str]] = mapped_column(UnicodeText, default=None)
 
+    # S6overlay / Docker configuration (for s6overlay process manager)
+    max_node_per_container: Mapped[int] = mapped_column(Integer, default=200)
+    min_container_count: Mapped[int] = mapped_column(Integer, default=1)
+    docker_image: Mapped[Optional[str]] = mapped_column(
+        UnicodeText, default="autonomi/node:latest"
+    )
+
+    # Node runtime flags
+    no_upnp: Mapped[bool] = mapped_column(Integer, default=1)  # SQLite uses 0/1 for boolean
+
     # Relationships
     containers: Mapped[list["Container"]] = relationship(
         back_populates="machine", cascade="all, delete-orphan"
@@ -145,6 +155,10 @@ class Machine(Base):
         max_concurrent_removals=1,
         node_removal_strategy="youngest",
         process_manager=None,
+        max_node_per_container=200,
+        min_container_count=1,
+        docker_image="autonomi/node:latest",
+        no_upnp=True,
     ):
         self.cpu_count = cpu_count
         self.node_cap = node_cap
@@ -182,6 +196,10 @@ class Machine(Base):
         self.max_concurrent_removals = max_concurrent_removals
         self.node_removal_strategy = node_removal_strategy
         self.process_manager = process_manager
+        self.max_node_per_container = max_node_per_container
+        self.min_container_count = min_container_count
+        self.docker_image = docker_image
+        self.no_upnp = no_upnp
 
     def __repr__(self):
         return (
@@ -237,6 +255,7 @@ class Machine(Base):
             "max_concurrent_removals": self.max_concurrent_removals,
             "node_removal_strategy": f"{self.node_removal_strategy}",
             "process_manager": f"{self.process_manager}" if self.process_manager else None,
+            "no_upnp": bool(self.no_upnp),
         }
 
 
@@ -257,6 +276,12 @@ class Container(Base):
     status: Mapped[str] = mapped_column(Unicode(32))  # running, stopped, etc.
     created_at: Mapped[int] = mapped_column(Integer)
 
+    # Port range tracking for s6overlay block-based allocation
+    port_range_start: Mapped[Optional[int]] = mapped_column(Integer, nullable=True)
+    port_range_end: Mapped[Optional[int]] = mapped_column(Integer, nullable=True)
+    metrics_port_range_start: Mapped[Optional[int]] = mapped_column(Integer, nullable=True)
+    metrics_port_range_end: Mapped[Optional[int]] = mapped_column(Integer, nullable=True)
+
     # Relationships
     machine: Mapped["Machine"] = relationship(back_populates="containers")
     nodes: Mapped[list["Node"]] = relationship(
@@ -271,6 +296,10 @@ class Container(Base):
         status,
         created_at,
         machine_id=1,
+        port_range_start=None,
+        port_range_end=None,
+        metrics_port_range_start=None,
+        metrics_port_range_end=None,
     ):
         self.container_id = container_id
         self.name = name
@@ -278,6 +307,10 @@ class Container(Base):
         self.status = status
         self.created_at = created_at
         self.machine_id = machine_id
+        self.port_range_start = port_range_start
+        self.port_range_end = port_range_end
+        self.metrics_port_range_start = metrics_port_range_start
+        self.metrics_port_range_end = metrics_port_range_end
 
     def __repr__(self):
         return (
@@ -331,6 +364,8 @@ class Node(Base):
     version: Mapped[Optional[str]] = mapped_column(UnicodeText)
     # Root directory of the node
     root_dir: Mapped[str] = mapped_column(UnicodeText)
+    # Log directory of the node (optional, defaults to platform-specific location)
+    log_dir: Mapped[Optional[str]] = mapped_column(UnicodeText, nullable=True)
     # Node open port
     port: Mapped[int] = mapped_column(Integer)
     # Node metrics port
@@ -353,6 +388,35 @@ class Node(Base):
     shunned: Mapped[int] = mapped_column(Integer)
     # Number of connected peers as reported by node
     connected_peers: Mapped[int] = mapped_column(Integer, default=0)
+
+    # InfluxDB-specific metrics (collected from /metrics endpoint)
+    # Number of GET requests (not currently exposed by node, kept for compatibility)
+    gets: Mapped[int] = mapped_column(Integer, default=0)
+    # Number of PUT requests (from ant_node_put_record_ok_total)
+    puts: Mapped[int] = mapped_column(Integer, default=0)
+    # Memory usage in MB * 100 (from ant_networking_process_memory_used_mb, e.g., 97.8125 MB = 9781)
+    mem: Mapped[int] = mapped_column(Integer, default=0)
+    # CPU usage percentage * 100 (from ant_networking_process_cpu_usage_percentage, e.g., 0.0353% = 4)
+    cpu: Mapped[int] = mapped_column(Integer, default=0)
+    # Number of open connections (from ant_networking_open_connections)
+    open_connections: Mapped[int] = mapped_column(Integer, default=0)
+    # Total peers in routing table (from ant_networking_peers_in_routing_table)
+    total_peers: Mapped[int] = mapped_column(Integer, default=0)
+    # Number of bad peers (from ant_networking_bad_peers_count_total)
+    bad_peers: Mapped[int] = mapped_column(Integer, default=0)
+    # Relevant records count (from ant_networking_relevant_records)
+    rel_records: Mapped[int] = mapped_column(Integer, default=0)
+    # Maximum records capacity (from ant_networking_max_records)
+    max_records: Mapped[int] = mapped_column(Integer, default=0)
+    # Rewards balance as TEXT for 18-decimal precision (from ant_node_current_reward_wallet_balance)
+    rewards: Mapped[Optional[str]] = mapped_column(UnicodeText, default="0")
+    # Number of payments received (from ant_networking_received_payment_count)
+    payment_count: Mapped[int] = mapped_column(Integer, default=0)
+    # Live time in seconds (from ant_networking_live_time)
+    live_time: Mapped[int] = mapped_column(Integer, default=0)
+    # Estimated network size (from ant_networking_estimated_network_size)
+    network_size: Mapped[int] = mapped_column(Integer, default=0)
+
     # Timestamp of node first launch
     age: Mapped[int] = mapped_column(Integer)
     # Host ip for data
@@ -396,6 +460,7 @@ class Node(Base):
         machine_id=1,
         container_id=None,
         manager_type="systemd",
+        log_dir=None,
     ):
         self.id = id
         self.node_name = node_name
@@ -404,6 +469,7 @@ class Node(Base):
         self.binary = binary
         self.version = version
         self.root_dir = root_dir
+        self.log_dir = log_dir
         self.port = port
         self.metrics_port = metrics_port
         self.network = network
