@@ -29,17 +29,27 @@ from wnm.utils import (
 class LaunchdManager(ProcessManager):
     """Manage nodes as launchd user agents on macOS"""
 
-    def __init__(self, session_factory=None, firewall_type: str = None):
+    def __init__(self, session_factory=None, firewall_type: str = None, mode: str = None):
         """
         Initialize LaunchdManager.
 
         Args:
             session_factory: SQLAlchemy session factory (optional, for status updates)
             firewall_type: Type of firewall to use (defaults to "null" on macOS)
+            mode: Operation mode - "sudo" for system daemons with sudo, "user" for user agents (default)
         """
         super().__init__(firewall_type)
         self.S = session_factory
-        self.plist_dir = os.path.expanduser("~/Library/LaunchAgents")
+
+        # Determine if we're using system daemons or user agents based on mode parameter
+        # mode="sudo": Use system daemons in /Library/LaunchDaemons/ with sudo (future)
+        # mode="user" or None: Use user agents in ~/Library/LaunchAgents/ without sudo (default)
+        if mode == "sudo":
+            self.use_system_daemons = True
+            self.plist_dir = "/Library/LaunchDaemons"
+        else:
+            self.use_system_daemons = False
+            self.plist_dir = os.path.expanduser("~/Library/LaunchAgents")
 
         # Ensure plist directory exists
         os.makedirs(self.plist_dir, exist_ok=True)
@@ -59,24 +69,40 @@ class LaunchdManager(ProcessManager):
         uid = os.getuid()
         return f"gui/{uid}"
 
-    def _generate_plist_content(self, node: Node, binary_path: str) -> str:
+    def _generate_plist_content(self, node: Node, binary_path: str, machine_config=None) -> str:
         """
         Generate the plist XML content for a node.
 
         Args:
             node: Node database record
             binary_path: Path to the node binary in the node's directory
+            machine_config: Machine configuration (optional, will query if not provided)
 
         Returns:
             XML string for the plist file
         """
+        # Get machine config if not provided
+        if machine_config is None and self.S:
+            from wnm.config import S
+            from wnm.models import Machine
+            from sqlalchemy import select
+
+            with S() as session:
+                result = session.execute(select(Machine)).first()
+                if result:
+                    machine_config = result[0]
+
         label = self._get_service_label(node)
         log_file = os.path.join(LOG_DIR, f"antnode{node.node_name}.log")
 
         # Build program arguments array
-        args = [
-            binary_path,
-            "--no-upnp",  # Disable UPnP (not needed/available on macOS in many cases)
+        args = [binary_path]
+
+        # Add --no-upnp if configured (defaults to True for backwards compatibility)
+        if machine_config and getattr(machine_config, 'no_upnp', True):
+            args.append("--no-upnp")
+
+        args.extend([
             "--bootstrap-cache-dir",
             BOOTSTRAP_CACHE_DIR,
             "--root-dir",
@@ -94,7 +120,7 @@ class LaunchdManager(ProcessManager):
             "--rewards-address",
             node.wallet,
             node.network,
-        ]
+        ])
 
         # Build ProgramArguments XML
         args_xml = "\n".join(f"        <string>{arg}</string>" for arg in args)
@@ -149,7 +175,7 @@ class LaunchdManager(ProcessManager):
 """
         return plist_content
 
-    def create_node(self, node: Node, binary_path: str) -> bool:
+    def create_node(self, node: Node, binary_path: str) -> NodeProcess:
         """
         Create and start a new node as a launchd user agent.
 
@@ -158,7 +184,7 @@ class LaunchdManager(ProcessManager):
             binary_path: Path to the antnode binary (typically ~/.local/bin/antnode)
 
         Returns:
-            True if node was created successfully
+            NodeProcess with metadata if successful, None if creation failed
         """
         logging.info(f"Creating launchd node {node.id}")
 
@@ -169,20 +195,20 @@ class LaunchdManager(ProcessManager):
             os.makedirs(log_dir, exist_ok=True)
         except OSError as err:
             logging.error(f"Failed to create directories: {err}")
-            return False
+            return None
 
         # Copy binary to node directory (each node gets its own copy)
         node_binary_path = os.path.join(node.root_dir, "antnode")
         try:
             if not os.path.exists(binary_path):
                 logging.error(f"Source binary not found: {binary_path}")
-                return False
+                return None
             shutil.copy2(binary_path, node_binary_path)
             # Make it executable
             os.chmod(node_binary_path, 0o755)
         except (OSError, shutil.Error) as err:
             logging.error(f"Failed to copy binary: {err}")
-            return False
+            return None
 
         # Generate plist file
         plist_path = self._get_plist_path(node)
@@ -193,7 +219,7 @@ class LaunchdManager(ProcessManager):
                 f.write(plist_content)
         except OSError as err:
             logging.error(f"Failed to write plist file: {err}")
-            return False
+            return None
 
         # Load the service with launchctl
         try:
@@ -206,7 +232,7 @@ class LaunchdManager(ProcessManager):
             logging.info(f"Loaded launchd service: {self._get_service_label(node)}")
         except subprocess.CalledProcessError as err:
             logging.error(f"Failed to load service: {err.stderr}")
-            return False
+            return None
 
         # Enable firewall port
         if not self.enable_firewall_port(
@@ -214,7 +240,11 @@ class LaunchdManager(ProcessManager):
         ):
             logging.warning(f"Failed to enable firewall for port {node.port}")
 
-        return True
+        # Return NodeProcess with basic info (launchd doesn't provide external IDs)
+        return NodeProcess(
+            node_id=node.id,
+            status=RESTARTING,  # Node is starting up
+        )
 
     def start_node(self, node: Node) -> bool:
         """
@@ -229,9 +259,27 @@ class LaunchdManager(ProcessManager):
         logging.info(f"Starting launchd node {node.id}")
 
         plist_path = self._get_plist_path(node)
+
+        # If plist doesn't exist, recreate it (node directory should exist)
         if not os.path.exists(plist_path):
-            logging.error(f"Plist file not found: {plist_path}")
-            return False
+            logging.info(f"Plist file not found, recreating: {plist_path}")
+
+            # Get the binary path from the node's root directory
+            node_binary_path = os.path.join(node.root_dir, "antnode")
+
+            if not os.path.exists(node_binary_path):
+                logging.error(f"Node binary not found: {node_binary_path}")
+                return False
+
+            # Generate and write the plist file
+            plist_content = self._generate_plist_content(node, node_binary_path)
+            try:
+                with open(plist_path, "w") as f:
+                    f.write(plist_content)
+                logging.info(f"Recreated plist file: {plist_path}")
+            except OSError as err:
+                logging.error(f"Failed to write plist file: {err}")
+                return False
 
         try:
             subprocess.run(
