@@ -69,7 +69,7 @@ class SystemdManager(ProcessManager):
             # Create user service directory if it doesn't exist
             os.makedirs(self.service_dir, exist_ok=True)
 
-    def create_node(self, node: Node, binary_path: str) -> bool:
+    def create_node(self, node: Node, binary_path: str) -> NodeProcess:
         """
         Create and start a new node as a systemd service.
 
@@ -78,10 +78,25 @@ class SystemdManager(ProcessManager):
             binary_path: Path to the antnode binary
 
         Returns:
-            True if node was created successfully
+            NodeProcess with metadata if successful, None if creation failed
         """
         logging.info(f"Creating systemd node {node.id}")
 
+        # Get machine config to check no_upnp setting
+        machine_config = None
+        if self.S:
+            from wnm.config import S
+            from wnm.models import Machine
+            from sqlalchemy import select
+
+            try:
+                with S() as session:
+                    result = session.execute(select(Machine)).first()
+                    if result:
+                        machine_config = result[0]
+            except Exception as e:
+                logging.warning(f"Failed to get machine config: {e}")
+
         # Prepare service name
         service_name = f"antnode{node.node_name}.service"
         log_dir = f"{LOG_DIR}/antnode{node.node_name}"
@@ -97,7 +112,7 @@ class SystemdManager(ProcessManager):
                 )
             except subprocess.CalledProcessError as err:
                 logging.error(f"Failed to create directories: {err}")
-                return False
+                return None
         else:
             # Non-root: create in user paths without sudo
             try:
@@ -105,7 +120,7 @@ class SystemdManager(ProcessManager):
                 os.makedirs(log_dir, exist_ok=True)
             except OSError as err:
                 logging.error(f"Failed to create directories: {err}")
-                return False
+                return None
 
         # Copy binary to node directory
         if self.use_system_services:
@@ -118,7 +133,7 @@ class SystemdManager(ProcessManager):
                 )
             except subprocess.CalledProcessError as err:
                 logging.error(f"Failed to copy binary: {err}")
-                return False
+                return None
         else:
             # Non-root: copy as current user
             try:
@@ -127,7 +142,7 @@ class SystemdManager(ProcessManager):
                 os.chmod(binary_dest, 0o755)
             except (OSError, shutil.Error) as err:
                 logging.error(f"Failed to copy binary: {err}")
-                return False
+                return None
 
         # Change ownership (only when running as root)
         # When running as non-root user, files remain owned by current user
@@ -141,7 +156,7 @@ class SystemdManager(ProcessManager):
                 )
             except subprocess.CalledProcessError as err:
                 logging.error(f"Failed to change ownership: {err}")
-                return False
+                return None
 
         # Build systemd service unit
         env_string = f'Environment="{node.environment}"' if node.environment else ""
@@ -156,12 +171,32 @@ class SystemdManager(ProcessManager):
         else:
             user_line = ""  # User services run as the invoking user
 
+        # Build ExecStart command with conditional --no-upnp
+        exec_args = [
+            binary_in_node_dir,
+            "--bootstrap-cache-dir", BOOTSTRAP_CACHE_DIR,
+            "--root-dir", node.root_dir,
+            "--port", str(node.port),
+            "--enable-metrics-server",
+            "--metrics-server-port", str(node.metrics_port),
+            "--log-output-dest", log_dir,
+            "--max-log-files", "1",
+            "--max-archived-log-files", "1",
+        ]
+
+        # Add --no-upnp if configured (defaults to True for backwards compatibility)
+        if machine_config and getattr(machine_config, 'no_upnp', True):
+            exec_args.append("--no-upnp")
+
+        exec_args.extend(["--rewards-address", node.wallet, node.network])
+        exec_start = " ".join(exec_args)
+
         service_content = f"""[Unit]
 Description=antnode{node.node_name}
 [Service]
 {env_string}
 {user_line}
-ExecStart={binary_in_node_dir} --bootstrap-cache-dir {BOOTSTRAP_CACHE_DIR} --root-dir {node.root_dir} --port {node.port} --enable-metrics-server --metrics-server-port {node.metrics_port} --log-output-dest {log_dir} --max-log-files 1 --max-archived-log-files 1 --rewards-address {node.wallet} {node.network}
+ExecStart={exec_start}
 Restart=always
 #RestartSec=300
 """
@@ -180,7 +215,7 @@ Restart=always
                 )
             except subprocess.CalledProcessError as err:
                 logging.error(f"Failed to write service file: {err}")
-                return False
+                return None
         else:
             # User services: write directly to ~/.config/systemd/user
             try:
@@ -188,7 +223,7 @@ Restart=always
                     f.write(service_content)
             except OSError as err:
                 logging.error(f"Failed to write service file: {err}")
-                return False
+                return None
 
         # Reload systemd
         try:
@@ -199,10 +234,17 @@ Restart=always
             )
         except subprocess.CalledProcessError as err:
             logging.error(f"Failed to reload systemd: {err}")
-            return False
+            return None
 
         # Start the node
-        return self.start_node(node)
+        if not self.start_node(node):
+            return None
+
+        # Return NodeProcess with basic info (systemd doesn't provide external IDs)
+        return NodeProcess(
+            node_id=node.id,
+            status=RESTARTING,  # Node is starting up
+        )
 
     def start_node(self, node: Node) -> bool:
         """
