@@ -10,6 +10,7 @@ from unittest.mock import MagicMock, patch
 from wnm.executor import ActionExecutor
 from wnm.models import Node
 from wnm.common import RUNNING, STOPPED, DISABLED, UPGRADING
+from wnm.process_managers.base import NodeProcess
 
 
 class TestNodeNameParsing:
@@ -66,7 +67,7 @@ class TestForcedAddAction:
         """Test forced add action creates a new node"""
         mock_expanduser.return_value = "/tmp/antnode"
         mock_manager = MagicMock()
-        mock_manager.create_node.return_value = True
+        mock_manager.create_node.return_value = NodeProcess(node_id=1, pid=12345, status="RUNNING")
         mock_get_manager.return_value = mock_manager
 
         executor = ActionExecutor(lambda: db_session)
@@ -806,6 +807,22 @@ class TestForcedTeardownAction:
         # Should remove 4 out of 5 nodes
         assert result["removed_count"] == 4
 
+    @patch("wnm.executor.ActionExecutor._get_process_manager")
+    def test_force_teardown_dry_run(self, mock_get_manager, db_session, multiple_nodes):
+        """Test forced teardown in dry-run mode"""
+        mock_manager = MagicMock()
+        mock_manager.teardown_cluster.return_value = False
+        mock_get_manager.return_value = mock_manager
+
+        executor = ActionExecutor(lambda: db_session)
+
+        result = executor._force_teardown_cluster({}, dry_run=True)
+
+        assert result["status"] == "cluster-teardown"
+        # Should not actually remove nodes
+        remaining = db_session.query(Node).count()
+        assert remaining == 5
+
 
 class TestCountParameter:
     """Test count parameter functionality across actions"""
@@ -818,7 +835,10 @@ class TestCountParameter:
         """Test adding multiple nodes with count parameter"""
         mock_expanduser.return_value = "/tmp/antnode"
         mock_manager = MagicMock()
-        mock_manager.create_node.return_value = True
+        # Return different NodeProcess objects for each call
+        mock_manager.create_node.side_effect = [
+            NodeProcess(node_id=i, pid=10000 + i, status="RUNNING") for i in range(1, 4)
+        ]
         mock_get_manager.return_value = mock_manager
 
         executor = ActionExecutor(lambda: db_session)
